if [ ! -e /etc/lftp.conf ]
then
    /usr/bin/mkdir -p /etc
    /usr/bin/cp /etc/defaults/etc/lftp.conf /etc/lftp.conf
fi

rm -f /usr/share/icons/hicolor/icon-theme.cache
